.. image:: /_static/images/repository-banner.png
   :align: center
   :width: 100%
   :alt: Ansys Solutions A

####################################################################################################
Ansys Solutions {{ cookiecutter.__solution_display_name }} |version|
####################################################################################################

.. grid:: 1
   :gutter: 3

   .. grid-item-card:: Getting Started
      :link-type: doc
      :link: getting_started/index

      Instructions for installing and configuring the solution.

.. grid:: 1
   :gutter: 3

   .. grid-item-card:: User Guide
      :link-type: doc
      :link: user_guide/index

      Instructions for using the solution.

.. grid:: 1
   :gutter: 3

   .. grid-item-card:: Examples
      :link-type: doc
      :link: examples

      Examples of how to use the solution.

.. grid:: 1
   :gutter: 3

   .. grid-item-card:: Release Notes
      :link-type: doc
      :link: changelog

      Information about the latest release.

.. toctree::
   :hidden:
   :maxdepth: 3

   getting_started/index
   user_guide/index
   examples
   changelog
